@@ -91,7 +91,10 @@ QString AboutDialogPrivate::aboutText() const
         "<p>%2</p>"
         "<p>%3</p>"
         "<p>%4</p>"
-        "<p>%5</p>")
+        "<p>%5</p>"
+        "<p>%6</p>"
+        "<p>%7</p>"
+        )
         .arg(
             tr("Advanced, easy-to-use, and fast desktop environment based on Qt technologies.",
                "About dialog, 'About' tab text"),
@@ -100,7 +103,11 @@ QString AboutDialogPrivate::aboutText() const
             tr("Copyright: © %1-%2 %3", "About dialog, 'About' tab text")
                 .arg(QStringLiteral("2010"), QDate::currentDate().toString(QStringLiteral("yyyy")), QStringLiteral("LXQt team")),
             tr("Homepage: %1", "About dialog, 'About' tab text")
-                .arg(QStringLiteral("<a href=\"https://lxqt.github.io\">https://lxqt.github.io</a>")),
+                .arg(QStringLiteral("<a href=\"https://lxqt-project.org\">https://lxqt-project.org</a>")),
+           tr("Wiki: %1", "About dialog, 'About' tab text")
+                .arg(QStringLiteral("<a href=\"https://github.com/lxqt/lxqt/wiki\">https://github.com/lxqt/lxqt/wiki</a>")),
+           tr("Development: %1", "About dialog, 'About' tab text")
+                .arg(QStringLiteral("<a href=\"https://github.com/lxqt/\">https://github.com/lxqt</a>")),
             tr("License: %1", "About dialog, 'About' tab text")
                 .arg(QStringLiteral("<a href=\"https://www.gnu.org/licenses/lgpl-2.1.html\">GNU Lesser General Public License version 2.1 or later</a>"
                      " and partly under the "
@@ -112,9 +119,9 @@ QString AboutDialogPrivate::authorsText() const
 {
     return QStringLiteral("<p>%1</p><p>%2</p>").arg(
                 tr("LXQt is developed by the <a %1>LXQt Team and contributors</a>.", "About dialog, 'Authors' tab text")
-                    .arg(QStringLiteral(" href=\"https://github.com/lxqt/lxqt\"")),
+                    .arg(QStringLiteral(" href=\"https://github.com/lxqt\"")),
                 tr("If you are interested in working with our development team, <a %1>join us</a>.", "About dialog, 'Authors' tab text")
-                    .arg(QStringLiteral("href=\"https://lxqt.github.io\""))
+                    .arg(QStringLiteral("href=\"https://github.com/orgs/lxqt/people\""))
                 );
 }
 
